@@ -1,6 +1,7 @@
 """
 Tests for the tasks defined in this repo
 """
+import json
 import logging
 from dataclasses import asdict
 from dataclasses import dataclass
@@ -16,6 +17,7 @@ from dkist_processing_common._util.scratch import WorkflowFileSystem
 from dkist_processing_common.models.tags import Tag
 from dkist_processing_common.tests.conftest import FakeGQLClient
 
+from dkist_processing_test.models.parameters import TestParameters
 from dkist_processing_test.tasks.exercise_numba import ExerciseNumba
 from dkist_processing_test.tasks.fail import FailTask
 from dkist_processing_test.tasks.fake_science import GenerateCalibratedData
@@ -41,6 +43,8 @@ class FakeConstantDb:
         "U",
         "V",
     )  # A tuple because lists aren't allowed on dataclasses
+    CONTRIBUTING_PROPOSAL_IDS: tuple[str] = ("abc", "def")
+    CONTRIBUTING_EXPERIMENT_IDS: tuple[str] = ("ghi", "jkl")
 
 
 @pytest.fixture()
@@ -73,7 +77,13 @@ def test_fail_task(fail_task):
 
 
 @pytest.fixture()
-def generate_calibrated_data_task(tmp_path, recipe_run_id):
+def generate_calibrated_data_task(
+    tmp_path,
+    recipe_run_id,
+    assign_input_dataset_doc_to_task,
+    parameter_file_object_key,
+    random_parameter_hdulist,
+):
     number_of_frames = 10
     with GenerateCalibratedData(
         recipe_run_id=recipe_run_id, workflow_name="GenerateCalibratedData", workflow_version="VX.Y"
@@ -89,10 +99,21 @@ def generate_calibrated_data_task(tmp_path, recipe_run_id):
         # load input data
         for idx, input_frame in enumerate(input_frame_set):
             hdu = input_frame.hdu()
+            hdu.data = (
+                np.ones(hdu.data.shape, dtype=int) * 10
+            )  # Because input data will be ints in test system
             hdu.header["DSPSNUM"] = 1
             hdul = fits.HDUList([hdu])
             file_name = f"input_{idx}.fits"
             task.fits_data_write(hdu_list=hdul, tags=Tag.input(), relative_path=file_name)
+
+        # Write parameter file
+        hdul = random_parameter_hdulist[0]
+        task.fits_data_write(hdu_list=hdul, tags=Tag.parameter(parameter_file_object_key))
+
+        # This needs to be after we've tagged the parameter file
+        assign_input_dataset_doc_to_task(task)
+
         # result
         yield task, number_of_frames
         # teardown
@@ -101,6 +122,38 @@ def generate_calibrated_data_task(tmp_path, recipe_run_id):
     # disconnect
 
 
+@pytest.fixture(scope="session")
+def input_dataset_document_parameters_part_with_file(parameter_file_object_key):
+    param_name = "test_random_data"
+    value = {
+        "__file__": {"bucket": "foo", "objectKey": parameter_file_object_key},
+    }
+    value_id = randint(1000, 2000)
+    values = [
+        {
+            "parameterValueId": value_id,
+            "parameterValue": json.dumps(value),
+            "parameterValueStartDate": "1946-11-20",
+        }
+    ]
+    parameter = {"parameterName": param_name, "parameterValues": values}
+    parameters_list = [parameter]
+
+    return parameters_list
+
+
+@pytest.fixture(scope="session")
+def assign_input_dataset_doc_to_task(input_dataset_document_parameters_part_with_file):
+    def update_task(task):
+        doc_path = task.scratch.workflow_base_path / "dataset_parameters.json"
+        with open(doc_path, "w") as f:
+            f.write(json.dumps(input_dataset_document_parameters_part_with_file))
+        task.tag(doc_path, Tag.input_dataset_parameters())
+        task.parameters = TestParameters(task.input_dataset_parameters)
+
+    return update_task
+
+
 def test_generate_calibrated_data(generate_calibrated_data_task, mocker):
     """
     Given: A GenerateCalibratedData task
